---
title: <span class="badge object-type-scalar"></span> KilobytesPerSecond
---
# <span class="badge object-type-scalar"></span> KilobytesPerSecond

Data rate: kilobytes/sec

## Definition

```python
# Data rate: kilobytes/sec
KilobytesPerSecond: typing.Literal["KBs"] = "KBs"
```
